@@ -65,7 +65,7 @@ package Net::Shadowsocks::Client;
                 my ( $client_socket, $client_host, $client_port ) = @_;
 
                 #AE::log info => "Got new client connection: $client_host:$client_port";
-                my $addr_to_send = '';
+                my $addr_to_send = undef;
                 my $server_iv;
                 my $decrypt_subkey;
                 my $stage = 0;
@@ -97,7 +97,7 @@ package Net::Shadowsocks::Client;
                         my $chandle = shift;
                         my $client_buffer = $chandle->rbuf();
 
-                        if ( $client_buffer eq '' ) 
+                        if ( length($client_buffer)  == 0 ) 
                         {
                             return;
                         }
@@ -208,7 +208,7 @@ package Net::Shadowsocks::Client;
                                             {
                                                 my $rhandle = shift;
                                                 my $incoming_data = $rhandle->rbuf();
-                                                my $decrypted_data = '';
+                                                my $decrypted_data = undef;
                                                 unless ( defined($server_iv) ) 
                                                 {
                                                     if (length($incoming_data) < length($iv))
@@ -404,7 +404,7 @@ package Net::Shadowsocks::Client;
                                                     $chandle->push_write($decrypted_data);
                                                     if ($self->{method} !~ /gcm$/ and $self->{method} !~ /poly1305$/)
                                                     {
-                                                        $rhandle->{rbuf} = '';
+                                                        $rhandle->{rbuf} = undef;
                                                     }
                                                  }
                                              }
@@ -439,10 +439,10 @@ package Net::Shadowsocks::Client;
                             {
                                 my $plain_data = $client_buffer;
                                 my $encrypted_data;
-                                if ( $addr_to_send ne '' ) 
+                                if ( defined($addr_to_send )) 
                                 {
                                     $plain_data = $addr_to_send . $client_buffer;
-                                    $addr_to_send = '';
+                                    $addr_to_send = undef;
                                 }
 
                                 if ( $self->{method} eq 'rc4-md5'  ) 
@@ -531,7 +531,7 @@ package Net::Shadowsocks::Client;
                                 }
                             }
                         }
-                        $chandle->{rbuf} = '';
+                        $chandle->{rbuf} = undef;
                     },
                 );
             },
