@@ -46,13 +46,13 @@
             map { ( $_ => $args{$_} ) }
               qw(password server server_port method),
         }, $class;
-        if ( $self->{server} eq 'localhost' )
+        if ( $self->{server} eq "localhost" )
          {
             undef $self->{server};
         }
         unless (defined($self->{method}))
         {
-            $self->{method} = 'spritz';
+            $self->{method} = "spritz";
         } 
         my $tcp_server;
         $tcp_server = AnyEvent::Socket::tcp_server
@@ -101,7 +101,7 @@
                         else 
                         {
                             my $incoming_data = $client_buffer;
-                            my $decrypted_data = '';
+                            my $decrypted_data = undef;
                             unless ( defined($client_iv) ) 
                             {
                                  if(length($incoming_data) < length($iv) )
@@ -370,7 +370,7 @@
                                                       
                                                           if ($self->{method} !~ /gcm$/ and $self->{method} !~ /poly1305$/)
                                                           {
-                                                              $chandle->{rbuf} = '';
+                                                              $chandle->{rbuf} = undef;
                                                           }
                                                       }
                                                   },
@@ -414,7 +414,7 @@
                                                       my $plain_data = $remote_buffer;
                                                       my $encrypted_data;
                                                
-                                                      if ( $self->{method} eq 'rc4-md5')
+                                                      if ( $self->{method} eq "rc4-md5")
                                                       {
                                                           $encrypted_data = $encryptor->RC4($plain_data );    
                                                       }
@@ -425,7 +425,7 @@
                                                       }
                                                       elsif($self->{method} =~ /^chacha20/)
                                                       {
-                                                          if($self->{method} eq 'chacha20-ietf')
+                                                          if($self->{method} eq "chacha20-ietf")
                                                           {
                                                               #$encrypted_data = $encryptor->process($plain_data);
                                                               #my $pt_len = length($plain_data)  % 64;
@@ -439,10 +439,10 @@
                                                           }
                                                           else
                                                           {
-                                                              my $data_len_pt = pack('n',length($plain_data));
-                                                              my $data_len_ct_withtag = $encryptor ->ietf_encrypt($data_len_pt,'',$encrypt_nonce,$encrypt_subkey);
+                                                              my $data_len_pt = pack("n",length($plain_data));
+                                                              my $data_len_ct_withtag = $encryptor ->ietf_encrypt($data_len_pt,undef,$encrypt_nonce,$encrypt_subkey);
                                                               $encrypt_nonce = $encrypt_nonce->increment();
-                                                              my $data_ct_withtag  =  $encryptor->ietf_encrypt($plain_data,'',$encrypt_nonce,$encrypt_subkey);
+                                                              my $data_ct_withtag  =  $encryptor->ietf_encrypt($plain_data,undef,$encrypt_nonce,$encrypt_subkey);
                                                               $encrypt_nonce = $encrypt_nonce->increment();
                                                               $encrypted_data = $data_len_ct_withtag . $data_ct_withtag;
                                                               carp length($encrypted_data);
@@ -453,16 +453,16 @@
                                                           carp $encrypt_nonce;
                                                           $encryptor->iv_add($encrypt_nonce);
                                                           carp length($plain_data);
-                                                          my $header_len_pt = pack('n',length($plain_data));
+                                                          my $header_len_pt = pack("n",length($plain_data));
                                                           carp $header_len_pt;
                                                           carp length($header_len_pt);
-                                                          $encryptor->adata_add('');
+                                                          $encryptor->adata_add(undef);
                                                           my $header_len_ct = $encryptor ->encrypt_add($header_len_pt,);
                                                           my $header_len_tag = $encryptor->encrypt_done();
                                                           $encrypt_nonce = $encrypt_nonce->increment();
                                                           $encryptor->reset();
                                                           $encryptor->iv_add($encrypt_nonce);
-                                                          $encryptor->adata_add('');
+                                                          $encryptor->adata_add(undef);
                                                           my $header_ct = $encryptor->encrypt_add($plain_data);
                                                           my $header_tag = $encryptor->encrypt_done();
                                                           $encrypt_nonce = $encrypt_nonce->increment();
@@ -486,7 +486,7 @@
                                                           $datatosend = $encrypted_data;
                                                       }
                                                       $clienthandler->push_write($datatosend);
-                                                      $rhandle->{rbuf} = '';
+                                                      $rhandle->{rbuf} = undef;
                                                   }
                                              );
                                         }
@@ -498,7 +498,7 @@
                                else
                                {
 
-                                     if ($self->{method} eq 'rc4-md5' )
+                                     if ($self->{method} eq "rc4-md5" )
                                      {
                                           $decrypted_data = $decryptor->RC4($incoming_data );
                                      }
@@ -508,7 +508,7 @@
                                      }
                                      elsif($self->{method} =~ /^chacha20/)
                                      {
-                                        if ($self->{method} eq 'chacha20-ietf')
+                                        if ($self->{method} eq "chacha20-ietf")
                                         {
                                            #$decrypted_data = $decryptor->process($incoming_data);
                                            #my $ct_len = length($incoming_data)  % 64;
@@ -534,7 +534,7 @@
                                                             my $data_len_pt;
                                                             eval
                                                             {
-                                                                $data_len_pt = $decryptor->ietf_decrypt($data_len_ct, '', $decrypt_nonce, $decrypt_subkey);
+                                                                $data_len_pt = $decryptor->ietf_decrypt($data_len_ct, undef, $decrypt_nonce, $decrypt_subkey);
                                                             };
                                                             if ( $@ ) 
                                                             {
@@ -543,7 +543,7 @@
                                                             } 
                                                             else 
                                                             {
-                                                                my $data_len = unpack('n',$data_len_pt); 
+                                                                my $data_len = unpack("n",$data_len_pt); 
                                                                 #carp "Decrypted data length: $data_len\n";
                                                                 my $chunk_len = $data_len + 34;
                                                                 if (length($incoming_data) < $chunk_len)
@@ -553,7 +553,7 @@
                                                                 else
                                                                 {
                                                                     $decrypt_nonce = $decrypt_nonce->increment();
-                                                                    $decrypted_data .= $decryptor->ietf_decrypt(substr($incoming_data,18,$data_len + 16),'',$decrypt_nonce,$decrypt_subkey);
+                                                                    $decrypted_data .= $decryptor->ietf_decrypt(substr($incoming_data,18,$data_len + 16),undef,$decrypt_nonce,$decrypt_subkey);
                                                                      if ( $@ ) 
                                                                      {
                                                                          AE::log error =>  "data forged!";
@@ -584,7 +584,7 @@
                                                {
                                                             my $header_len_ct = substr($incoming_data,0,2); 
                                                             $decryptor->iv_add($decrypt_nonce);
-                                                            $decryptor->adata_add('');
+                                                            $decryptor->adata_add(undef);
                                                             my $header_len_pt = $decryptor->decrypt_add($header_len_ct);
                                                             my $header_len_tag = substr($incoming_data,2,16);
                                                             my $length_result = $decryptor->decrypt_done($header_len_tag);
@@ -595,7 +595,7 @@
                                                             } 
                                                             else 
                                                             {
-                                                                my $header_len = unpack('n',$header_len_pt); 
+                                                                my $header_len = unpack("n",$header_len_pt); 
                                                                 #carp "Decrypted data length: $header_len\n";
                                                                 my $chunk_len = $header_len + 34;
                                                                 if (length($incoming_data) < $chunk_len)
@@ -607,7 +607,7 @@
                                                                     $decrypt_nonce = $decrypt_nonce->increment();
                                                                     $decryptor->reset();
                                                                     $decryptor->iv_add($decrypt_nonce);
-                                                                    $decryptor->adata_add('');
+                                                                    $decryptor->adata_add(undef);
                                                                     $decrypted_data = $decryptor->decrypt_add(substr($incoming_data,18,$header_len ));
                                                                     my $header_tag = substr($incoming_data,18 + $header_len,16);
                                                                     my $header_result = $decryptor->decrypt_done($header_tag);
@@ -649,7 +649,7 @@
                        } 
                        if ($self->{method} !~ /gcm$/ and $self->{method} !~ /poly1305$/)
                        {
-                            $chandle->{rbuf} = '';
+                            $chandle->{rbuf} = undef;
                        } 
                     }
                 );
@@ -658,13 +658,13 @@
             {
                     my $client_socket = shift;
                     setsockopt($client_socket,,SOL_SOCKET, SO_REUSEADDR, 1);
-                    if ( $_osname eq 'linux' and  -e '/proc/sys/net/ipv4/tcp_fastopen') 
+                    if ( $_osname eq "linux" and  -e "/proc/sys/net/ipv4/tcp_fastopen") 
                     {
-                        if (-r '/proc/sys/net/ipv4/tcp_fastopen')
+                        if (-r "/proc/sys/net/ipv4/tcp_fastopen")
                         {
                             my $_tfo = do 
                             {
-                                local ( @ARGV, $/ ) = '/proc/sys/net/ipv4/tcp_fastopen';<>;
+                                local ( @ARGV, $/ ) = "/proc/sys/net/ipv4/tcp_fastopen";<>;
                             };
                             if ( $_tfo == 2 or $_tfo == 3 ) 
                             {
@@ -673,9 +673,9 @@
                             }
                         }
                     }
-                    elsif ( $_osname eq 'darwin' ) 
+                    elsif ( $_osname eq "darwin" ) 
                     {
-                        my $_version_major = substr( $_osvers, 0, index( $_osvers, '.' ) );
+                        my $_version_major = substr( $_osvers, 0, index( $_osvers, "." ) );
                         if ( $_version_major >= 15 ) 
                         {
                             setsockopt( $client_socket, IPPROTO_TCP, TCP_FASTOPEN, 1 );
@@ -753,10 +753,10 @@ Project website https://osdn.net/projects/ssperl/
     example use:
 
     my $foo = Net::Shadowsocks::Server->new(
-    password => ' 49923641 ',
-    server => ' jp . ssip . club ',
+    password => "49923641",
+    server => "jp . ssip . club",
     server_port => 23333,
-    method => 'spritz',
+    method => "spritz",
     );
 
     This is all you need to do. Take a look at server.pl under eg directory for a compelete example on how to
